awesomecv: Awesome CV template

View source: R/awesomecv.R

awesomecvR Documentation

Awesome CV template

Description

Awesome CV is LaTeX template for a CV or Résumé inspired by Fancy CV: https://github.com/posquit0/Awesome-CV

Usage

awesomecv(
  ...,
  latex_engine = "xelatex",
  page_total = FALSE,
  show_footer = TRUE,
  font_scale = 1
)

Arguments

...

Arguments passed to cv_document.

latex_engine

LaTeX engine for producing PDF output. Options are "pdflatex", "lualatex", "xelatex" and "tectonic".

page_total

If TRUE, the total number of pages is shown in the footer.

show_footer

If TRUE, a footer showing your name, document name, and page number.

font_scale

Numeric multiplier applied to hard-coded font sizes in the Awesome‑CV class (default = 1). Use values like 0.95–1.10.

Value

An R Markdown output format object.

Preview

Template preview

Author(s)

Mitchell O'Hara-Wild, theme by Byungjin Park (@posquit0)


vitae documentation built on Aug. 21, 2026, 9:07 a.m.